#!/usr/bin/python
# -*- coding: UTF-8 -*-

import os

def get_os_from_file():
    files=["/etc/redhat-release","/etc/SuSE-release","/etc/release","/etc/issue"]
    for afile in files:
        exist =  os.path.exists(afile)
        if exist:
            #print afile
            f=open(afile,'r')
            while True:
                line=f.readline()
                if not line:
                    f.close()
                    print("The operating system can not resolved")
                    exit(1)
                    break
                if line.find("openSUSE") != -1 or line.find("release")!=-1 or line.find("Mint") != -1 or line.find("Ubuntu") != -1:
                    f.close()
                    if line.find('\n') != -1:
                        line = line.replace('\n','')
                    if line.find('\\n') != -1:
                        line = line.replace('\\n','')
                    if line.find('\\l') != -1:
                        line = line.replace('\\l','')
                    return line
                    break
            f.close()
            print("The operating system can not resolved")
            exit(1)
            break
    print("The operating system can not resolved")
    exit(1)
   
        

if __name__=="__main__":
    print(get_os_from_file())



#!/usr/bin/python
# -*- coding: UTF-8 -*-


import json


def save_to_file(filename, jsondata):
    if isinstance(filename,str) == False:
        print("The filename should be a string.")
        exit(1)
    if isinstance(jsondata,dict) == False:
        print("The json data should be a dict")
        exit(1)
    with open(filename,"w") as f:
        json.dump(jsondata,f)
        return True



def load_from_file(filename):
    if isinstance(filename, str) == False:
        print("The filename should be a string.")
        exit(1)

    with open(filename, "r") as f:
        load_dict = json.load(f)
        return load_dict


if __name__ == "__main__":
    test_dict = {"site": "kit", "service_type": "13"}
    save_to_file("config.json",test_dict)
    res=load_from_file("config.json")
    print(res)
    print(type(res))




#!/usr/bin/python
# -*- coding: UTF-8 -*-

import subprocess
import os

_services={}

_services['b2safe']=['b2safe','irods']
_services['gitlab']=['gitlab']
_services['svmon']=['spring','angular']
_services['b2access']=['b2access_unity']
_services['b2find']=['b2find','ckan']
_services['b2handle']=['handle','epic']
_services['B2HANDLE']=['handle','epic']
_services['b2drop']=['nextcloud']
_services['dpmt']=['plone']
_services['eudat_website']=['drupal']
_services['b2gether']=['b2gether']
_services['gocdb']=['creg']
_services['b2access']=['unity']
_services['svmon_client']=['client']

_rpm_packages={}
_rpm_packages['b2safe']='b2safe'
_rpm_packages['irods']='irods-icat'

_tags={}
_tags['svmon']=['3.1','1.7']

def in_service_list(service_type):
    #print(type(service_type))
    #print _services.has_key(service_type)
    if service_type == None or service_type == "" or isinstance(service_type,str) == False:
        print("The service type argument should be a non-empty string")
        exit(1)
    if service_type in _services.keys():
        return True
    else:
        print("Your service type is unsupported. Please type --list-service-type see supported services.")
        exit(1)

def get_service_name(service_type):
    if service_type == None or service_type == "" or isinstance(service_type,str) == False:
        print("The service type argument should be a non-empty string")
        exit(1)
    if in_service_list(service_type):
        return _services.get(service_type)
    return []


def get_service_tag(service_type,configs=None):
    if service_type == None or service_type == "" or isinstance(service_type,str) == False:
        print("The service type argument should be a non-empty string")
        exit(1)
    if in_service_list(service_type) == False:
        print("The service type is currently unsupported in svmon client")
        exit(1)

    tags=[]
    if service_type == "svmon_client":
        tmp = subprocess.Popen('pip show svmon_client', shell=True, stdout = subprocess.PIPE)
        tmp = subprocess.Popen('grep Version', shell = True, stdin=tmp.stdout, stdout = subprocess.PIPE)
        tmp = tmp.communicate()
        tmp=tmp[0]
        if tmp == '' or tmp == None:
            print("No svmon client has been installed, please refer to https://gitlab.eudat.eu/jie.yuan/pysvmon")
            exit(1)
        ltmp=tmp.split('\n')
        ltmp=ltmp[0].split(':')
        if ltmp == None or len(ltmp) < 2:
            print("SVMON client can not be resolved, please check for installation")
            exit(1)
        ltmp=ltmp[1]
        ltmp.replace("\n","")
        ltmp.replace(" ", "")

        if ltmp == "":
            print("the version of svmon client can not resolved. Please check installation of svmon client")
            exit(1)
        tags.append(ltmp)
        return tags
    elif service_type == "gitlab":
        #tags.append("ce15") #currently for test
        tmp = get_by_rpm_packages("gitlab", 0 , 1)
        if tmp == "":
            print("no gitlab version can be resolved")
            exit(1)
        tags.append(tmp)
        return tags
    elif service_type == "b2safe":
        tmp=get_by_rpm_packages("b2safe")
        if tmp == "":
            print("no b2safe version can be resolved")
            exit(1)
        tags.append(tmp)
        tmp=get_by_rpm_packages("irods-icat")
        if tmp == "":
            print("no icat version can be resolved")
            exit(1)
        tags.append(tmp)
        return tags
    elif service_type == "svmon":
        return _tags['svmon']
    elif service_type == "b2handle" or service_type == "B2HANDLE":
        if configs.has_key('epic_version_file') and configs.has_key('handle_server_path'):
            tags=[]
            tags.append(get_epic_version(configs.get('epic_version_file')))
            tags.append(get_handle_server(configs.get('handle_server_path')))
            return tags
        else:
            print("No b2handle configuration to get versions")
            exit(1)







# for package version that can be accessed via rpm management
def get_by_rpm_packages(software,start=0,end=0):
    if isinstance(software,str)  == False or software == "" or software == None:
        print("software name should be a non-empty string")
        exit(1)
    if isinstance(start,int) == False or isinstance(end, int) == False:
        print("The input of indices should be integers to fetch correct version,")
        exit(1)
    tmp = subprocess.Popen("rpm -qa", shell=True, stdout=subprocess.PIPE)
    tmp = subprocess.Popen('grep ' + software, shell=True, stdin=tmp.stdout, stdout=subprocess.PIPE)
    tmp = tmp.communicate()
    tmp = tmp[0]
    if  tmp == None or tmp == "":
        print("no rpm packages can be found for " + software)
        exit(1)
    ind=tmp.find(software)
    ind=ind+len(software)
    ltmp=tmp[ind+1:len(tmp)].split('-')

    if len(ltmp) > end:
        if start == end:
            return ltmp[start]
        elif start < end:
            res=""
            for i in range(start,end+1):
                res=res+ltmp[i]
            return res
        else:
            print("The start index should be smaller than end index for a correct rpm package resolver")
    else:
        print(software +" version not resolved")
        exit(1)


def get_user():
    tmp=subprocess.Popen("whoami",shell=True,stdout=subprocess.PIPE)
    tmp=tmp.communicate()
    #print(tmp)
    return tmp[0].replace('\n','')


def get():
    tags=get_service_tag("svmon_client")
    return tags[0]

def get_epic_version(epic_version_file):
    exist =  os.path.exists(epic_version_file)
    if exist:
        f=open(epic_version_file,'r')
        while True:
            line=f.readline()
            if not line:
                f.close()
                print("The epic version can not be resolved from "+ epic_version_file)
                exit(1)
                break
            if line.find("VERSION=") != -1 :
                f.close()
                if line.find("\'") != -1:
                    line=line.replace("\'","")
                for i in range(len(line)):
                    if line[i].isupper() == True:
                        line=line.replace(line[i],"=")
                if line.find("=") != -1:
                    line=line.replace("=","")
                return line
                break

        print("No epic version information in " + epic_version_file)
        exit(1)

          

def get_handle_server(handle_server_path):
    tmp = subprocess.Popen(handle_server_path, shell=True, stdout = subprocess.PIPE)
    tmp = tmp.communicate()
    tmp = tmp[0].split('\n')
    tmp = tmp[0]
    for i in range(len(tmp)):
        if tmp[i].isalpha() == True:
            tmp = tmp.replace(tmp[i],"=")
    if tmp.find("=")!= -1:
        tmp = tmp.replace("=","")
    print(tmp)

    return "10"

if __name__ == "__main__":
    #print(in_service_list("aa"))
    print(get())
   # print(get_rpm("vim"))
    #print(get_service_by_name("mariadb-client"))
   # print(get_service_by_name("gitlab"))
    #print(get_service_by_name("irods"))
    



#!/usr/bin/python
# -*- coding: UTF-8 -*-

import os
import json
import subprocess
from . import services
from . import json_operations

class SVMONReport:

    def __init__(self):
        self.site=""
        self.host=""
        self.service_names=[]
        self.service_type=""
        self.operating_system=""  
        self.tags=[]
        cwd = os.path.dirname(services.__file__)
        filename = cwd + "/config.json"
        with open(filename, 'r') as f:
            load_dict= json.load(f)
            #print(type(load_dict))
           # for k,v in load_dict.items():
        #    print("%s : %s " %(k,v))
            self.site=str(load_dict['site'])
            self.host=str(load_dict['host'])
            self.service_type=str(load_dict['service_type'])
            #print(type(self.service_type))
            #print(self.service_type)
            #print("mark")
            #if services.in_service_list(self.service_type) == False:
            #    print("service type not configured")
            #self.service_names=services.get_service_name(self.service_type)
           # print(self.service_names)
            #self.tags=services.get_service_tag(self.service_type)
           # print(self.tags)
            #print(self.service_names)
            #print(self.tags)
            

    def refresh_service_name_and_tag(self):
        if services.in_service_list(self.service_type) == False:
            print("service type not configured")
        self.service_names = services.get_service_name(self.service_type)
       
        b2handle_config= {}
        if self.service_type == 'b2handle' or self.service_type == "B2HANDLE":
            cwd = os.path.dirname(services.__file__)
            filename = cwd + "/config.json"
            with open(filename, 'r') as f:
                load_dict= json.load(f)
                if load_dict.has_key('epic_version_file') and load_dict.has_key('handle_server_path'):
                    b2handle_config['epic_version_file'] = load_dict.get('epic_version_file')
                    b2handle_config['handle_server_path'] = load_dict.get('handle_server_path')
                    self.tags = services.get_service_tag(self.service_type,b2handle_config)
                else:
                    print("No configuration for b2handle, please see svmon help")
                    exit(1)
        else:
            self.tags = services.get_service_tag(self.service_type)

    
    def get_site(self):
        return self.site

    def get_host(self):
        return self.host

    def get_service_names(self):
        return self.service_names

    def get_service_type(self):
        return self.service_type

    def get_tags(self):
        return self.tags
    
    def set_site(self,site):
        if isinstance(site,str):
            self.site=site

    def set_host(self,host):
        if isinstance(host,str):
            self.host=host

    def set_service_names(self,service_names):
        if isinstance(service_names,list):
            self.service_names=service_names

    def set_service_type(self,service_type):
        if isinstance(service_type,str):
            self.service_type=service_type

    def set_tags(self,tags):
        if isinstance(tags,list):
            self.tags=tags
   
    def set_operating_system(self,operating_system):
        if isinstance(operating_system,str):
            self.operating_system=operating_system

    def set_service_names_and_tags(self,service_name,tag):
        this.service_names.append(service_name)
        this.tags.append(tag)
       

    def print_report(self):
        if len(self.service_names) > 0:
            res=[]
            if self.service_names== None or len(self.service_names ) < 1:
                print("no service names is resolved at your host")
                exit(1)
            if  self.tags == None or len(self.tags) < 1:
                print("no service component version is resolved at your host")
                exit(1)
            for i in range(len(self.service_names)):
                res.append(self.site+'\t'+self.host+'\t'+self.operating_system+'\t'+self.service_type+'\t'+self.service_names[i]+'\t'+self.tags[i]+'\n')
           # print len(self.service_names)
            #print "here"
            return res
        else:
            print( len(self.service_names))
            #print "there"
            return []



    def jsonify(self):
        if len(self.service_names) > 0:
            res = {}
            res['site']= self.site
            res['host'] = self.host
            res['operating_system'] = self.operating_system
            res['service_type'] = self.service_type
            res['service_names'] = self.service_names
            res['tags'] = self.tags
            return res
        else:
            print("No services to be jsonified")
            return {}
    
    def save_b2handle_config_to_json(self,handle_server_path=None,epic_version_file=None):
        if handle_server_path == None and epic_version_file == None:
            print("No b2handle configuration input")
            exit(-1)
        if handle_server_path != None and isinstance(handle_server_path,str) == False:
            print("Handle server path should be a string")
            exit(-1)
        if epic_version_file != None and isinstance(epic_version_file,str) == False:
            print("Handle server path should be a string")
            exit(-1)
        if epic_version_file == "" and handle_server_path == "":
            print("No input for b2handle configuration")
            exit(-1)

        res={}
        res['site']= self.site
        res['host'] = self.host
        res['service_type'] = self.service_type
        if epic_version_file != "" and handle_server_path != "":
            res['epic_version_file'] = epic_version_file
            res['handle_server_path'] = handle_server_path
        elif epic_version_file == "" and handle_server_path != "":
            res['handle_server_path'] = handle_server_path
            print("No epic_version_file input")
            cwd = os.path.dirname(services.__file__)
            filename = cwd + "/config.json"
            with open(filename, 'r') as f:
                load_dict= json.load(f)
                if load_dict.has_key('epic_version_file'):
                    res['epic_version_file'] = load_dict.get('epic_version_file')
        elif epic_version_file != "" and handle_server_path == "":
            res['epic_version_file'] = epic_version_file
            print("No handle_server_path input")
            cwd = os.path.dirname(services.__file__)
            filename = cwd + "/config.json"
            with open(filename, 'r') as f:
                load_dict= json.load(f)
                if load_dict.has_key('handle_server_path'):
                    res['handle_server_path'] = load_dict.get('handle_server_path')

        cwd = os.path.dirname(services.__file__)
        filename = cwd + "/config.json"
        if services.get_user() != 'root' and cwd.find('usr') != -1 and cwd.find('lib') != -1:
            print('You need root priviledges to write the configuration file')
            exit(1)
        success = json_operations.save_to_file(filename,res)
        if success == False:
            print("Save json data failed")
            exit(1)
        else:
            print("Saved B2HANLE configuration")



    def save_to_json(self):
        if self.site != "" and self.site != None:
            res = {}
            res['site']= self.site
            res['host'] = self.host
            res['service_type'] = self.service_type
            cwd = os.path.dirname(services.__file__)
            #print(cwd)
            #print(type(cwd))
            filename = cwd + "/config.json"
            if services.get_user() != 'root' and cwd.find('usr') != -1 and cwd.find('lib') != -1:
                print('You need root priviledges to write the configuration file')
                exit(1)

            success = json_operations.save_to_file(filename,res)
            if success == False:
                print("Save json data failed")
                exit(1)
        else:
            print("No services to be jsonified")
            exit(1)
    
        
    
 

    def set_pair(self,key,value):
        if isinstance(key,str) == False:
            print("Key should be a string")
            exit(1)

        if key == "site":
            self.set_site(value)
        elif key == "host":
            self.set_host(value)
        elif key == "service_type":
            self.set_service_type(value)
        elif key == "operating_system":
            self.set_operating_system(value)
        elif key == "service_names":
            self.set_service_names(value)
        elif key == "tags":
            self.set_tags(value)
        else :
            print("such key is not supporteed: %s\n" %key)
            exit(1)


    def check_site(self):
        return True


    def check_host(self):
        return True

    def print_config_file(self):
        cwd = os.path.dirname(services.__file__)
        filename = cwd + "/config.json"
        with open(filename, 'r') as f:
            load_dict = json.load(f)
            print("The following are your current configurations: ")
            print('site=  ' +str(load_dict['site']))
            print('host=  ' +str(load_dict['host']))
            print('service type =  ' +str(load_dict['service_type']))
            print('Please use svmon --site <SITE> --host <HOST> --type <TYPE> --dump to change your configuration')



    def send_report_to_svmon_server(self):
       import requests as re
       url = 'https://svmon.eudat.eu:8443/api/serviceComponent/jsonreport'
       headers = {}
       headers['Content-Type'] = 'application/json'
       cwd = os.path.dirname(services.__file__)
       certs = cwd + "/chain_TERENA_SSL_CA_3.pem"
       for i in range(len(self.service_names)):
           res = {}
           res['siteName']=self.site
           res['hostNameId']=self.host
           res['operatingSystem']=self.operating_system
           res['serviceType']=self.service_type
           res['serviceComponentName']=self.service_names[i]
           res['tagAtSite']=self.tags[i]
           r = re.post(url, headers=headers, data=json.dumps(res), verify=certs)
           if (r.status_code != 201):
               print('Sending report failed, please check your configuration')
               exit(1)
       print('Report has been sent successfully.')
       exit(0)



if __name__=="__main__":
    re=SVMONReport()
    re.save_to_json()



#!/usr/bin/python
# -*- coding: UTF-8 -*-


from setuptools import setup, find_packages


setup( 
name='svmon-client-pilot',
version='1.1.0',
packages=['svmon_client'],
scripts=['svmon','pakiti-client'],
package_data={'' : ['*.json','*.pem']},
description='This is a python implementation of SVMON client',
long_description=open('README.rst').read(), 
author='Jie Yuan',
author_email='jie.yuan@kit.edu',
maintainer='Jie Yuan',
maintainer_email='jie.yuan@kit.edu',
license='MIT License',
platforms=["all"],
url='https://gitlab.eudat.eu/jie.yuan/pysvmon',
classifiers=[ 
    'Development Status :: 4 - Beta', 
    'Operating System :: OS Independent',
    'Intended Audience :: Developers',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python',
    'Programming Language :: Python :: Implementation',
    'Programming Language :: Python :: 2.7',
    'Topic :: Software Development :: Libraries' ]
)
